@@ -407,8 +407,10 @@ tb_bool_t tb_file_info(tb_char_t const* path, tb_file_info_t* info)
         if (st.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) info->type = TB_FILE_TYPE_DIRECTORY;
         else if (st.dwFileAttributes != 0xffffffff) info->type = TB_FILE_TYPE_FILE;
 
-        // TODO does not support symlink now
+        // is symlink?
         info->flags = TB_FILE_FLAG_NONE;
+        if (st.dwFileAttributes & FILE_ATTRIBUTE_REPARSE_POINT)
+            info->flags |= TB_FILE_FLAG_LINK;
 
         // file size
         info->size = ((tb_hize_t)st.nFileSizeHigh << 32) | (tb_hize_t)st.nFileSizeLow;
@@ -436,17 +438,43 @@ tb_bool_t tb_file_copy(tb_char_t const* path, tb_char_t const* dest, tb_size_t f
     tb_wchar_t full1[TB_PATH_MAXN];
     if (!tb_path_absolute_w(dest, full1, TB_PATH_MAXN)) return tb_false;
 
+    // copy link
+    tb_file_info_t info = {0};
+    if (flags & TB_FILE_COPY_LINK && tb_file_info(path, &info) && info.flags & TB_FILE_FLAG_LINK)
+    {
+        tb_file_mkdir(full1);
+        if (tb_kernel32()->CopyFileExW && tb_kernel32()->CopyFileExW(full0, full1, tb_null, tb_null, FALSE, COPY_FILE_COPY_SYMLINK))
+            return tb_true;
+
+        // we should read file content to copy it
+        tb_bool_t ok = tb_false;
+        tb_file_ref_t ifile = tb_file_init(path, TB_FILE_MODE_RW);
+        tb_file_ref_t ofile = tb_file_init(dest, TB_FILE_MODE_RW | TB_FILE_MODE_CREAT | TB_FILE_MODE_TRUNC);
+        if (ifile && ofile)
+        {
+            tb_hize_t writ = 0;
+            tb_hize_t size = tb_file_size(ifile);
+            while (writ < size)
+            {
+                tb_hong_t real = tb_file_writf(ofile, ifile, writ, size - writ);
+                if (real > 0) writ += real;
+                else break;
+            }
+            if (writ == size) ok = tb_true;
+        }
+
+        // exit file
+        if (ifile) tb_file_exit(ifile);
+        if (ofile) tb_file_exit(ofile);
+        return ok;
+    }
+
     // copy it
     if (!CopyFileW(full0, full1, FALSE))
     {
-        // make directory
         tb_file_mkdir(full1);
-
-        // copy it again
         return (tb_bool_t)CopyFileW(full0, full1, FALSE);
     }
-
-    // ok
     return tb_true;
 }
 tb_bool_t tb_file_create(tb_char_t const* path)
@@ -493,15 +521,21 @@ tb_bool_t tb_file_rename(tb_char_t const* path, tb_char_t const* dest)
 
     // rename it
     DWORD flags = MOVEFILE_COPY_ALLOWED | MOVEFILE_REPLACE_EXISTING | MOVEFILE_WRITE_THROUGH;
-    if (!MoveFileExW(full0, full1, flags))
-    {
-        // make directory
-        tb_file_mkdir(full1);
+    if (MoveFileExW(full0, full1, flags)) return tb_true;
 
-        // rename it again
-        return MoveFileExW(full0, full1, flags);
+    // try to create directories and rename it again
+    tb_file_mkdir(full1);
+    if (MoveFileExW(full0, full1, flags)) return tb_true;
+
+    // MoveFileExW will fail if it crosses drive, we can use copy/delete to rename file
+    if (CopyFileW(full0, full1, FALSE))
+    {
+        DWORD attrs = GetFileAttributesW(full0);
+        if (attrs & FILE_ATTRIBUTE_READONLY)
+            SetFileAttributesW(full0, attrs & ~FILE_ATTRIBUTE_READONLY);
+        return DeleteFileW(full0);
     }
-    return tb_true;
+    return tb_false;
 }
 tb_bool_t tb_file_link(tb_char_t const* path, tb_char_t const* dest)
 {
